Page 93 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 93

Home

    investigation and bring this information to the American
    people. The full one hour interview of Norman Dodd on
    video tape is available from, American Media, P. O. Box
    4646, Westlake Village, California.

    To understand why such goals were pursued by the
    trustees of the Carnegie Endowment for International

    Peace, it is helpful to understand the background of
    Andrew Carnegie. Born in Scotland, into a family of
    radical ideas, he came "to the United States with his

    parents in 1848. Here he rose from a $1.20 per week
    bobbin-boy to become one of the richest men in the

    world.

    With the right connections during the Civil War, he
    emerged at the end of that conflict well established in
    business. A master at dealing in government contracts,
    he was able to build an empire in the steel industry,
    selling his interests in 1901 for $250 million.

    When public resistance grew against his manipulation
    of government for profit, Carnegie learned that the best
    way to overcome a tarmmished image was to spend
    millions of dollars to establish a well-advertised

    reputation for philanthropy.

    Andrew Carmegie was one of the first people in
    America to call for a "League of Nations" and an
    international "peace army," in other words, one world
    government. Throughout his career, he worked with
    other prominent Americans toward the accomplishment
    of this goal. Although he made his vast fortune in the
    United States, he never became an American citizen.

    88

    The Secret side of History

    of dollars to

    establish a